@@ -369,6 +369,8 @@ class CommonAPISession:
         """
         operation_url = str(self.url + operation)
         response = self._http.request("POST", operation_url, body=message.encode('utf-8'), headers=request_headers)
+        if not response.data:
+            raise Exception(response.reason)
         return response.data
 
 
