@@ -20,8 +20,7 @@ def get_api_session():
     con_details = get_connectivity_context_details_dict()
     env_details = get_reservation_context_details_dict()
     return CloudShellAPISession(host=con_details['serverAddress'],
-                                username=con_details['adminUser'],
-                                password=con_details['adminPass'],
+                                token_id=con_details['adminAuthToken'],
                                 domain=env_details['domain'],
                                 cloudshell_api_scheme=con_details.get("tsAPIScheme", "http"),
                                 use_webapi_endpoint=con_details.get("useWebapiEndpoint", "false").lower()=="true")
